django_analyses.models package — django_analyses 0.0.3 documentation

# django_analyses.models package

## Subpackages

- django_analyses.models.input package
  - Subpackages
    - django_analyses.models.input.definitions package
      - Submodules
      - django_analyses.models.input.definitions.boolean_input_definition module
      - django_analyses.models.input.definitions.directory_input_definition module
      - django_analyses.models.input.definitions.file_input_definition module
      - django_analyses.models.input.definitions.float_input_definition module
      - django_analyses.models.input.definitions.input_definition module
      - django_analyses.models.input.definitions.input_definitions module
      - django_analyses.models.input.definitions.integer_input_definition module
      - django_analyses.models.input.definitions.list_input_definition module
      - django_analyses.models.input.definitions.messages module
      - django_analyses.models.input.definitions.number_input_definition module
      - django_analyses.models.input.definitions.string_input_definition module
      - Module contents
    - django_analyses.models.input.types package
      - Submodules
      - django_analyses.models.input.types.boolean_input module
      - django_analyses.models.input.types.directory_input module
      - django_analyses.models.input.types.file_input module
      - django_analyses.models.input.types.float_input module
      - django_analyses.models.input.types.input_types module
      - django_analyses.models.input.types.integer_input module
      - django_analyses.models.input.types.list_input module
      - django_analyses.models.input.types.number_input module
      - django_analyses.models.input.types.string_input module
      - Module contents
  - Submodules
  - django_analyses.models.input.input module
  - django_analyses.models.input.input_specification module
  - django_analyses.models.input.utils module
  - Module contents
- django_analyses.models.managers package
  - Submodules
  - django_analyses.models.managers.analysis module
  - django_analyses.models.managers.analysis_version module
  - django_analyses.models.managers.input_definition module
  - django_analyses.models.managers.input_specification module
  - django_analyses.models.managers.output_definition module
  - django_analyses.models.managers.output_specification module
  - django_analyses.models.managers.run module
  - Module contents
- django_analyses.models.output package
  - Subpackages
    - django_analyses.models.output.definitions package
      - Submodules
      - django_analyses.models.output.definitions.file_output_definition module
      - django_analyses.models.output.definitions.float_output_definition module
      - django_analyses.models.output.definitions.output_definition module
      - django_analyses.models.output.definitions.output_definitions module
      - Module contents
    - django_analyses.models.output.types package
      - Submodules
      - django_analyses.models.output.types.file_output module
      - django_analyses.models.output.types.float_output module
      - django_analyses.models.output.types.output_types module
      - Module contents
  - Submodules
  - django_analyses.models.output.output module
  - django_analyses.models.output.output_specification module
  - Module contents
- django_analyses.models.pipeline package
  - Submodules
  - django_analyses.models.pipeline.node module
  - django_analyses.models.pipeline.pipe module
  - django_analyses.models.pipeline.pipeline module
  - Module contents

## Submodules

## django_analyses.models.analysis module

class `django_analyses.models.analysis.` `Analysis`(id, created, modified, description, title, category)

  Bases: `django_extensions.db.models.TitleDescriptionModel`, `django_extensions.db.models.TimeStampedModel`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `category`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `category_id`
  `get_next_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=True, **kwargs)
  `get_next_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=True, **kwargs)
  `get_previous_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=False, **kwargs)
  `get_previous_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=False, **kwargs)
  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `inputspecification_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `objects` = <django_analyses.models.managers.analysis.AnalysisManager object>
  `outputspecification_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `version_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

## django_analyses.models.analysis_version module

class `django_analyses.models.analysis_version.` `AnalysisVersion`(id, created, modified, title, description, analysis, input_specification, output_specification, run_method_key, fixed_run_method_kwargs, nested_results_attribute)

  Bases: `django_extensions.db.models.TitleDescriptionModel`, `django_extensions.db.models.TimeStampedModel`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `analysis`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `analysis_id`
  `extract_results`(results) → dict
  `fixed_run_method_kwargs`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `get_interface`()
  `get_interface_initialization_kwargs`(**kwargs) → dict
  `get_next_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=True, **kwargs)
  `get_next_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=True, **kwargs)
  `get_previous_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=False, **kwargs)
  `get_previous_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=False, **kwargs)
  `get_run_method_kwargs`(**kwargs) → dict
  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  property `input_definitions`
  `input_specification`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `input_specification_id`
  `nested_results_attribute`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  property `nested_results_parts`
  `node_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `objects` = <django_analyses.models.managers.analysis_version.AnalysisVersionManager object>
  property `output_definitions`
  `output_specification`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `output_specification_id`
  `run`(**kwargs) → dict
  `run_interface`(**kwargs)
  `run_method_key`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `run_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `update_input_with_defaults`(**kwargs) → dict

## django_analyses.models.category module

class `django_analyses.models.category.` `Category`(id, created, modified, description, title, parent)

  Bases: `django_extensions.db.models.TitleDescriptionModel`, `django_extensions.db.models.TimeStampedModel`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `analysis_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `get_next_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=True, **kwargs)
  `get_next_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=True, **kwargs)
  `get_previous_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=False, **kwargs)
  `get_previous_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=False, **kwargs)
  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `objects` = <django.db.models.manager.Manager object>
  `parent`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `parent_id`
  `subcategories`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

## django_analyses.models.run module

class `django_analyses.models.run.` `Run`(id, created, modified, analysis_version, user)

  Bases: `django_extensions.db.models.TimeStampedModel`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `analysis_version`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `analysis_version_id`
  `base_input_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `base_output_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `delete`(using=None, keep_parents=False)
  `get_input_configuration`() → dict
  `get_input_set`() → django.db.models.query.QuerySet
  `get_next_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=True, **kwargs)
  `get_next_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=True, **kwargs)
  `get_output_configuration`() → dict
  `get_output_set`() → django.db.models.query.QuerySet
  `get_previous_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=False, **kwargs)
  `get_previous_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=False, **kwargs)
  `get_raw_input_configuration`() → dict
  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  property `input_configuration`
  property `input_defaults`
  property `input_set`
  `objects` = <django_analyses.models.managers.run.RunManager object>
  property `output_configuration`
  property `output_set`
  property `path`
  property `raw_input_configuration`
  `user`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `user_id`

## Module contents